@@ -5,6 +5,10 @@ dwtest <- function(formula, order.by = NULL, alternative = c("greater", "two.sid
   alternative <- match.arg(alternative)
 
   if(!inherits(formula, "formula")) {
+    if(!is.null(w <- weights(formula))) {
+      if(!isTRUE(all.equal(as.vector(w), rep(1L, length(w)))))
+        stop("weighted regressions are not supported")
+    }
     X <- if(is.matrix(formula$x))
            formula$x
          else model.matrix(terms(formula), model.frame(formula))
